@@ -3,9 +3,9 @@ build_time_vars = {'ABIFLAGS': '',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
- 'ALIGNOF_LONG': 4,
+ 'ALIGNOF_LONG': 8,
  'ALIGNOF_MAX_ALIGN_T': 8,
- 'ALIGNOF_SIZE_T': 4,
+ 'ALIGNOF_SIZE_T': 8,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
  'AR': '/usr/bin/ar',
@@ -20,7 +20,7 @@ build_time_vars = {'ABIFLAGS': '',
  'BOOTSTRAP_HEADERS': '\\',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'i386-unknown-openbsd7.7',
+ 'BUILD_GNU_TYPE': 'powerpc64-unknown-openbsd7.7',
  'BUILD_SCRIPTS_DIR': 'build/scripts-3.12',
  'BYTESTR_DEPS': '\\',
  'CC': 'cc -pthread',
@@ -60,9 +60,9 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/local/include',
  'CONFINCLUDEPY': '/usr/local/include/python3.12',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/pobj/Python-3.12.9/Python-3.12.9/coverage.info',
+ 'COVERAGE_INFO': '/usr/obj/ports/Python-3.12.10/Python-3.12.10/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/pobj/Python-3.12.9/Python-3.12.9/lcov-report',
+ 'COVERAGE_REPORT': '/usr/obj/ports/Python-3.12.10/Python-3.12.10/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
@@ -87,8 +87,8 @@ build_time_vars = {'ABIFLAGS': '',
  'DLINCLDIR': '.',
  'DLLLIBRARY': '',
  'DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754': 0,
- 'DOUBLE_IS_BIG_ENDIAN_IEEE754': 0,
- 'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 1,
+ 'DOUBLE_IS_BIG_ENDIAN_IEEE754': 1,
+ 'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 0,
  'DSYMUTIL': '',
  'DSYMUTIL_PATH': '',
  'DTRACE': '',
@@ -244,8 +244,8 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GAI_STRERROR': 1,
  'HAVE_GCC_ASM_FOR_MC68881': 0,
  'HAVE_GCC_ASM_FOR_X64': 0,
- 'HAVE_GCC_ASM_FOR_X87': 1,
- 'HAVE_GCC_UINT128_T': 0,
+ 'HAVE_GCC_ASM_FOR_X87': 0,
+ 'HAVE_GCC_UINT128_T': 1,
  'HAVE_GDBM_DASH_NDBM_H': 0,
  'HAVE_GDBM_H': 1,
  'HAVE_GDBM_NDBM_H': 0,
@@ -313,7 +313,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_KILLPG': 1,
  'HAVE_KQUEUE': 1,
  'HAVE_LANGINFO_H': 1,
- 'HAVE_LARGEFILE_SUPPORT': 1,
+ 'HAVE_LARGEFILE_SUPPORT': 0,
  'HAVE_LCHFLAGS': 0,
  'HAVE_LCHMOD': 0,
  'HAVE_LCHOWN': 1,
@@ -608,17 +608,17 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ZLIB_H': 0,
  'HAVE__GETPTY': 0,
  'HOSTRUNNER': '',
- 'HOST_GNU_TYPE': 'i386-unknown-openbsd7.7',
+ 'HOST_GNU_TYPE': 'powerpc64-unknown-openbsd7.7',
  'INCLDIRSTOMAKE': '/usr/local/include /usr/local/include '
                    '/usr/local/include/python3.12 '
                    '/usr/local/include/python3.12',
  'INCLUDEDIR': '/usr/local/include',
  'INCLUDEPY': '/usr/local/include/python3.12',
- 'INSTALL': '/pobj/Python-3.12.9/bin/install -c',
- 'INSTALL_DATA': '/pobj/Python-3.12.9/bin/install -c -m 644',
- 'INSTALL_PROGRAM': '/pobj/Python-3.12.9/bin/install -c -s -m 755',
- 'INSTALL_SCRIPT': '/pobj/Python-3.12.9/bin/install -c -m 755',
- 'INSTALL_SHARED': '/pobj/Python-3.12.9/bin/install -c -m 755',
+ 'INSTALL': '/usr/obj/ports/Python-3.12.10/bin/install -c',
+ 'INSTALL_DATA': '/usr/obj/ports/Python-3.12.10/bin/install -c -m 644',
+ 'INSTALL_PROGRAM': '/usr/obj/ports/Python-3.12.10/bin/install -c -s -m 755',
+ 'INSTALL_SCRIPT': '/usr/obj/ports/Python-3.12.10/bin/install -c -m 755',
+ 'INSTALL_SHARED': '/usr/obj/ports/Python-3.12.10/bin/install -c -m 755',
  'INSTSONAME': 'libpython3.12.so.0.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
@@ -655,14 +655,15 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBHACL_SHA2_OBJS': '\\',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
- 'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_32=1 -DANSI=1 '
-                    '-fno-strict-overflow -Wsign-compare -Wunreachable-code '
-                    '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe -flto=thin '
-                    '-g -std=c11 -Wextra -Wno-unused-parameter '
-                    '-Wno-missing-field-initializers -Wstrict-prototypes '
-                    '-Werror=implicit-function-declaration -fvisibility=hidden '
-                    '-I/usr/local/include -I./Include/internal -I. -I./Include '
-                    '-I/usr/local/include -fPIC -fPIC',
+ 'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 -DANSI=1 '
+                    '-DHAVE_UINT128_T=1 -fno-strict-overflow -Wsign-compare '
+                    '-Wunreachable-code -DNDEBUG -O2 -pipe   -fPIC -O2 -pipe '
+                    '-O2 -pipe -flto=thin -g -std=c11 -Wextra '
+                    '-Wno-unused-parameter -Wno-missing-field-initializers '
+                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
+                    '-fvisibility=hidden -I/usr/local/include '
+                    '-I./Include/internal -I. -I./Include -I/usr/local/include '
+                    '-fPIC -fPIC',
  'LIBMPDEC_HEADERS': '\\',
  'LIBMPDEC_OBJS': '\\',
  'LIBOBJDIR': 'Python/',
@@ -876,8 +877,8 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__DBM_CFLAGS': '-DUSE_NDBM',
  'MODULE__DBM_LDFLAGS': '',
  'MODULE__DBM_STATE': 'yes',
- 'MODULE__DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_32=1 '
-                           '-DANSI=1',
+ 'MODULE__DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 '
+                           '-DANSI=1 -DHAVE_UINT128_T=1',
  'MODULE__DECIMAL_DEPS': './Modules/_decimal/docstrings.h \\ '
                          'Modules/_decimal/libmpdec/libmpdec.a',
  'MODULE__DECIMAL_LDFLAGS': '-lm Modules/_decimal/libmpdec/libmpdec.a',
@@ -1055,15 +1056,18 @@ build_time_vars = {'ABIFLAGS': '',
                    '-I/usr/local/include -I./Include/internal -I. -I./Include '
                    '-I/usr/local/include -fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-L/usr/local/lib/ -flto=thin -g '
-                    '-L/pobj/Python-3.12.9/Python-3.12.9 -L/usr/local/lib/',
+                    '-L/usr/obj/ports/Python-3.12.10/Python-3.12.10 '
+                    '-L/usr/local/lib/',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/local/include',
  'PY_ENABLE_SHARED': 1,
  'PY_HAVE_PERF_TRAMPOLINE': 0,
  'PY_LDFLAGS': '-L/usr/local/lib/',
- 'PY_LDFLAGS_NODIST': '-flto=thin -g -L/pobj/Python-3.12.9/Python-3.12.9 '
+ 'PY_LDFLAGS_NODIST': '-flto=thin -g '
+                      '-L/usr/obj/ports/Python-3.12.10/Python-3.12.10 '
                       '-L/usr/local/lib/',
  'PY_LDFLAGS_NOLTO': '-L/usr/local/lib/ -flto=thin '
-                     '-L/pobj/Python-3.12.9/Python-3.12.9 -L/usr/local/lib/',
+                     '-L/usr/obj/ports/Python-3.12.10/Python-3.12.10 '
+                     '-L/usr/local/lib/',
  'PY_SQLITE_ENABLE_LOAD_EXTENSION': 1,
  'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
@@ -1088,7 +1092,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': '@READELF@',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/pobj/Python-3.12.9/Python-3.12.9',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.12.10/Python-3.12.10',
  'SCRIPTDIR': '/usr/local/lib',
  'SCRIPT_2TO3': 'build/scripts-3.12/2to3-3.12',
  'SCRIPT_IDLE': 'build/scripts-3.12/idle3.12',
@@ -1161,18 +1165,18 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_FLOAT': 4,
  'SIZEOF_FPOS_T': 8,
  'SIZEOF_INT': 4,
- 'SIZEOF_LONG': 4,
- 'SIZEOF_LONG_DOUBLE': 12,
+ 'SIZEOF_LONG': 8,
+ 'SIZEOF_LONG_DOUBLE': 8,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
  'SIZEOF_PTHREAD_KEY_T': 4,
- 'SIZEOF_PTHREAD_T': 4,
+ 'SIZEOF_PTHREAD_T': 8,
  'SIZEOF_SHORT': 2,
- 'SIZEOF_SIZE_T': 4,
+ 'SIZEOF_SIZE_T': 8,
  'SIZEOF_TIME_T': 8,
- 'SIZEOF_UINTPTR_T': 4,
- 'SIZEOF_VOID_P': 4,
+ 'SIZEOF_UINTPTR_T': 8,
+ 'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-312',
@@ -1193,10 +1197,11 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/pobj/Python-3.12.9/Python-3.12.9 ./python -E',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.12.10/Python-3.12.10 '
+               './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/pobj/Python-3.12.9/Python-3.12.9 ./python -E '
-               './Tools/scripts/run_tests.py',
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.12.10/Python-3.12.10 '
+               './python -E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'idlelib/idle_test \\',
  'TESTTIMEOUT': 1200,
  'TEST_MODULES': 'yes',
@@ -1223,10 +1228,10 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_NEXT_FRAMEWORK': 0,
  'WITH_PYMALLOC': 1,
  'WITH_VALGRIND': 0,
- 'X87_DOUBLE_ROUNDING': 1,
+ 'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/pobj/Python-3.12.9/Python-3.12.9',
- 'abs_srcdir': '/pobj/Python-3.12.9/Python-3.12.9',
+ 'abs_builddir': '/usr/obj/ports/Python-3.12.10/Python-3.12.10',
+ 'abs_srcdir': '/usr/obj/ports/Python-3.12.10/Python-3.12.10',
  'datarootdir': '/usr/local/share',
  'exec_prefix': '/usr/local',
  'prefix': '/usr/local',
